//
//  GoRunningInterfaceController.swift
//  TapALap WatchKit Extension
//
//  Created by Jeff Kelley on 10/23/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import WatchKit
import Foundation


class GoRunningInterfaceController: WKInterfaceController, TrackSelectionReceiver {
    
    @IBOutlet weak var trackNameLabel: WKInterfaceLabel!
    @IBOutlet weak var trackDistanceLabel: WKInterfaceLabel!
    
    var selectedTrack: Track?
    
    override func willActivate() {
        super.willActivate()
        
        updateTrackLabels()
    }
    
    lazy var distanceFormatter = NSLengthFormatter()
    
    func updateTrackLabels() {
        if let track = selectedTrack {
            trackNameLabel.setText(track.name)
            
            trackDistanceLabel.setText(
                distanceFormatter.stringFromMeters(track.lapDistance))
        }
        else {
            trackNameLabel.setText("None")
            trackDistanceLabel.setText(nil)
        }
    }
    
    @IBAction func trackButtonPressed() {
        if Track.savedTracks().count > 0 {
            presentControllerWithName("TrackSelection", context: self)
        }
        else {
            presentControllerWithName("TrackConfiguration", context: self)
        }
    }

    @IBAction func startRunButtonPressed() {
        guard let track = selectedTrack else {
            presentAlertControllerWithTitle("Error",
                message: "You need to select a track to run on!",
                preferredStyle: .Alert,
                actions: [
                    WKAlertAction(title: "OK",
                        style: .Default,
                        handler: {})
                ])
            
            return
        }
        
        let names = ["RunTimer"]
        
        WKInterfaceController.reloadRootControllersWithNames(names,
            contexts: [track])
    }
    
    func receiveTrack(track: Track) {
        selectedTrack = track
        updateTrackLabels()
        dismissController()
    }

}
