//
//  GoRunningInterfaceController.swift
//  TapALap WatchKit Extension
//
//  Created by Jeff Kelley on 10/23/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import WatchKit
import Foundation


class GoRunningInterfaceController: WKInterfaceController, TrackSelectionReceiver {
    
    @IBOutlet weak var trackNameLabel: WKInterfaceLabel!
    @IBOutlet weak var trackDistanceLabel: WKInterfaceLabel!
    @IBOutlet weak var averagePaceLabel: WKInterfaceLabel!
    @IBOutlet weak var chevronImage: WKInterfaceImage!
    
    var selectedTrack: Track?
    
    override func willActivate() {
        super.willActivate()
        
        updateTrackLabels()
        updateAveragePaceLabel(552)
        
        if let originalChevronImage = UIImage(named: "chevron") {
            chevronImage.setImage(originalChevronImage
                .imageFlippedForRightToLeftLayoutDirection())
        }
    }
    
    lazy var distanceFormatter = NSLengthFormatter()
    
    func updateTrackLabels() {
        if let track = selectedTrack {
            trackNameLabel.setText(track.name)
            
            trackDistanceLabel.setText(
                distanceFormatter.stringFromMeters(track.lapDistance))
        }
        else {
            trackNameLabel.setText(NSLocalizedString("None", comment: ""))
            trackDistanceLabel.setText(nil)
        }
    }
    
    @IBAction func trackButtonPressed() {
        if Track.savedTracks().count > 0 {
            presentControllerWithName("TrackSelection", context: self)
        }
        else {
            presentControllerWithName("TrackConfiguration", context: self)
        }
    }

    @IBAction func startRunButtonPressed() {
        guard let track = selectedTrack else {
            presentAlertControllerWithTitle(NSLocalizedString("Error", comment: ""),
                message: NSLocalizedString("You need to select a track to run on!",
                    comment: ""),
                preferredStyle: .Alert,
                actions: [
                    WKAlertAction(title: NSLocalizedString("OK", comment: ""),
                        style: .Default,
                        handler: {})
                ])
            
            return
        }
        
        let names = ["RunTimer"]
        
        WKInterfaceController.reloadRootControllersWithNames(names,
            contexts: [track])
    }
    
    
    func updateAveragePaceLabel(averagePace: NSTimeInterval) {
        let labelTextFormatter = NSDateComponentsFormatter()
        let labelAccessibilityLabelFormatter = NSDateComponentsFormatter()
        
        labelTextFormatter.allowedUnits = [.Minute, .Second]
        labelAccessibilityLabelFormatter.allowedUnits = [.Minute, .Second]
        
        labelTextFormatter.unitsStyle = .Positional
        labelAccessibilityLabelFormatter.unitsStyle = .SpellOut
        
        averagePaceLabel.setText(
            labelTextFormatter.stringFromTimeInterval(averagePace))
        
        averagePaceLabel.setAccessibilityLabel(
            labelAccessibilityLabelFormatter.stringFromTimeInterval(averagePace))
    }
    
    func receiveTrack(track: Track) {
        selectedTrack = track
        updateTrackLabels()
        dismissController()
    }

}
