//
//  RunTimerInterfaceController.swift
//  TapALap
//
//  Created by Jeff Kelley on 10/23/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import WatchKit
import Foundation


class RunTimerInterfaceController: WKInterfaceController {

    @IBOutlet weak var distanceLabel: WKInterfaceLabel!
    
    var track: Track!
    
    var lapTimes: [NSTimeInterval]?
    var startDate: NSDate?
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        guard let track = context as? Track else {
            fatalError("No track provided")
        }
        
        self.track = track
    }

    override func willActivate() {
        super.willActivate()
        
        if lapTimes == nil || startDate == nil {
            let userDefaults = NSUserDefaults.standardUserDefaults()
            
            if let date = userDefaults.objectForKey("StartDate") as? NSDate,
                times = userDefaults.objectForKey("LapTimes") as? [NSTimeInterval] {
                    startDate = date
                    lapTimes = times
            }
            else {
                startRun()
            }
        }
        
        updateDistanceLabel()
    }
    
    func startRun() {
        lapTimes = []
        startDate = NSDate()
        
        let userDefaults = NSUserDefaults.standardUserDefaults()
        userDefaults.setObject(startDate, forKey: "StartDate")
        userDefaults.setObject(lapTimes, forKey: "LapTimes")
        userDefaults.synchronize()
    }

    @IBAction func stopRunButtonPressed() {
        endRun()
    }
    
    func endRun() {
        let names = ["GoRunning", "RunLog"]
        
        let contexts: [AnyObject]?
        
        if let lapTimes = lapTimes, startDate = startDate {
            let distance = track.lapDistance * Double(lapTimes.count)
            
            let run = Run(distance: distance,
                laps: lapTimes,
                startDate: startDate)
            
            let userDefaults = NSUserDefaults.standardUserDefaults()
            userDefaults.removeObjectForKey("LapTimes")
            userDefaults.removeObjectForKey("StartDate")
            userDefaults.synchronize()
            
            contexts = [NSNull(), run]
        }
        else {
            contexts = nil
        }

        WKInterfaceController.reloadRootControllersWithNames(names,
            contexts: contexts)
    }
    
    lazy var lengthFormatter: NSLengthFormatter = {
        let formatter = NSLengthFormatter()
        formatter.numberFormatter.maximumSignificantDigits = 3
        return formatter
    }()
    
    func updateDistanceLabel() {
        guard let lapTimes = lapTimes where !lapTimes.isEmpty else {
            distanceLabel.setText("No laps finished!")
            return
        }
        
        let distance = track.lapDistance * Double(lapTimes.count)
        
        distanceLabel.setText(lengthFormatter.stringFromMeters(distance))
    }
    
    @IBAction func finishLapButtonPressed() {
        let lapFinishTime = NSDate()
        
        guard let startDate = startDate, lapTimes = lapTimes else { return }
        
        let totalRunDuration = lapFinishTime.timeIntervalSinceDate(startDate)
        
        let cumulativeLapDuration = lapTimes.reduce(0, combine: { $0 + $1 })
        
        let lapDuration = totalRunDuration - cumulativeLapDuration
        
        self.lapTimes?.append(lapDuration)
        
        updateDistanceLabel()
        
        let userDefaults = NSUserDefaults.standardUserDefaults()
        userDefaults.setObject(lapTimes, forKey: "LapTimes")
        userDefaults.synchronize()
    }
    
}
