//
//  Track.swift
//  TapALap
//
//  Created by Jeff Kelley on 10/23/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import Foundation

class Track {
    let name: String
    let lapDistance: Double // in meters
    
    let id: NSUUID
    
    init(name: String, lapDistance: Double) {
        self.name = name
        self.lapDistance = lapDistance
        
        id = NSUUID()
    }
    
    init?(id idString: String,
        dictionaryRepresentation dictionary: [String: AnyObject]) {
            guard let name = dictionary["Name"] as? String,
                lapDistance = dictionary["LapDistance"] as? Double,
                id = NSUUID(UUIDString: idString)
                else {
                    self.name = ""
                    self.lapDistance = 0
                    self.id = NSUUID()
                    
                    return nil
            }
            
            self.name = name
            self.lapDistance = lapDistance
            self.id = id
    }
    
    func dictionaryRepresentation() -> [String: AnyObject] {
        return ["Name": name, "LapDistance": lapDistance]
    }
    
    static func savedTracks() -> [Track] {
        guard let trackDictionaries = NSUserDefaults.standardUserDefaults()
            .objectForKey("SavedTracks") as? [String: [String: AnyObject]]
            else { return [] }
        
        return trackDictionaries.flatMap {
            Track.init(id: $0.0, dictionaryRepresentation: $0.1)
        }
    }
    
    func save() {
        var tracks = Track.savedTracks()
        
        guard !tracks.contains(self) else { return }
        
        tracks.append(self)
        
        var trackDictionaries: [String: [String: AnyObject]] = [:]
        
        for track in tracks {
            trackDictionaries[track.id.UUIDString] =
                track.dictionaryRepresentation()
        }
        
        NSUserDefaults.standardUserDefaults().setObject(trackDictionaries,
            forKey: "SavedTracks")
    }
    
}

func ==(lhs: Track, rhs: Track) -> Bool {
    return lhs.id == rhs.id &&
        lhs.name == rhs.name &&
        lhs.lapDistance == rhs.lapDistance
}

extension Track: Equatable {}
