//
//  InterfaceController.swift
//  Soccer WatchKit Extension
//
//  Created by Jeff Kelley on 8/2/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import WatchKit
import Foundation

class InterfaceController: WKInterfaceController {

    // MARK:- Types

    enum ButtonDirection: String {
        case Up = "↑"
        case Down = "↓"
        case Left = "←"
        case Right = "→"
    }

    // MARK:- UI Elements

    @IBOutlet weak var soccerBall: WKInterfaceGroup!
    @IBOutlet weak var soccerField: WKInterfaceGroup!
    @IBOutlet weak var verticalNudgeButton: WKInterfaceButton!
    @IBOutlet weak var horizontalNudgeButton: WKInterfaceButton!

    // MARK:- Properties

    var verticalDirection: ButtonDirection = .Down {
        didSet {
            verticalNudgeButton.setTitle(verticalDirection.rawValue)
        }
    }

    var horizontalDirection: ButtonDirection = .Right {
        didSet {
            horizontalNudgeButton.setTitle(horizontalDirection.rawValue)
        }
    }

    let ballSize: CGSize = CGSize(width: 20, height: 20)
    var currentInsets: UIEdgeInsets = UIEdgeInsetsZero

    var soccerFieldSize: CGSize {
        var frame = contentFrame
        frame.size.height -= 44
        return frame.size
    }

    // MARK:-

    let kickDistance: CGFloat = 10
    let kickDuration = 1.0 / 3.0

    @IBAction func verticalNudgeButtonPressed() {
        if verticalDirection == .Down {
            currentInsets.top += kickDistance

            if currentInsets.top + ballSize.height + kickDistance >
                soccerFieldSize.height {
                    verticalDirection = .Up
            }
        }
        else {
            currentInsets.top -= kickDistance

            if currentInsets.top - kickDistance < 0 {
                verticalDirection = .Down
            }
        }

        animateWithDuration(kickDuration) {
            self.soccerField.setContentInset(self.currentInsets)
        }
    }

    @IBAction func horizontalNudgeButtonPressed() {
        if horizontalDirection == .Right {
            currentInsets.left += kickDistance

            if currentInsets.left + ballSize.width + kickDistance >
                soccerFieldSize.width {
                horizontalDirection = .Left
            }
        }
        else {
            currentInsets.left -= kickDistance

            if currentInsets.left - kickDistance < 0 {
                horizontalDirection = .Right
            }
        }

        animateWithDuration(kickDuration) {
            self.soccerField.setContentInset(self.currentInsets)
        }
    }

}
