//
//  RunTimerInterfaceController.swift
//  TapALap
//
//  Created by Jeff Kelley on 10/23/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import WatchKit
import Foundation


class RunTimerInterfaceController: WKInterfaceController {

    @IBOutlet weak var distanceLabel: WKInterfaceLabel!
    
    lazy var track: Track = Track(name: "Track", lapDistance:  500)
    
    var lapTimes: [NSTimeInterval]?
    var startDate: NSDate?
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        // Configure interface objects here.
    }

    override func willActivate() {
        super.willActivate()
        
        if lapTimes == nil || startDate == nil {
            lapTimes = []
            startDate = NSDate()
        }
        
        updateDistanceLabel()
    }

    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }

    @IBAction func stopRunButtonPressed() {
        endRun()
    }
    
    /*
    func endRun() {
    let names = ["GoRunning", "RunLog"]
    
    WKInterfaceController.reloadRootControllersWithNames(names,
    	contexts: nil)
    }
    */
    
    func endRun() {
        let names = ["GoRunning", "RunLog"]
        
        let contexts: [AnyObject]?
        
        if let lapTimes = lapTimes, startDate = startDate {
            let distance = track.lapDistance * Double(lapTimes.count)
            
            let run = Run(distance: distance,
                laps: lapTimes,
                startDate: startDate)
            
            contexts = [NSNull(), run]
        }
        else {
            contexts = nil
        }
        
        WKInterfaceController.reloadRootControllersWithNames(names,
            contexts: contexts)
    }
    
    lazy var lengthFormatter: NSLengthFormatter = {
        let formatter = NSLengthFormatter()
        formatter.numberFormatter.maximumSignificantDigits = 3
        return formatter
    }()
    
    func updateDistanceLabel() {
        guard let lapTimes = lapTimes where !lapTimes.isEmpty else {
            distanceLabel.setText("No laps finished!")
            return
        }
        
        let distance = track.lapDistance * Double(lapTimes.count)
        
        distanceLabel.setText(lengthFormatter.stringFromMeters(distance))
    }
    
    @IBAction func finishLapButtonPressed() {
        let lapFinishTime = NSDate()
        
        guard let startDate = startDate, lapTimes = lapTimes else { return }
        
        let totalRunDuration = lapFinishTime.timeIntervalSinceDate(startDate)
        
        let cumulativeLapDuration = lapTimes.reduce(0, combine: { $0 + $1 })
        
        let lapDuration = totalRunDuration - cumulativeLapDuration
        
        self.lapTimes?.append(lapDuration)
        
        updateDistanceLabel()
    }
    
}
