//
//  RunLogInterfaceController.swift
//  TapALap
//
//  Created by Jeff Kelley on 10/30/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import WatchKit
import Foundation


class RunLogInterfaceController: WKInterfaceController {
    
    @IBOutlet weak var runTable: WKInterfaceTable!
    
    var runs: [Run]?
    
    lazy var dateFormatter: NSDateFormatter = {
        let dateFormatter = NSDateFormatter()
        dateFormatter.dateStyle = .ShortStyle
        return dateFormatter
    }()
    
    lazy var distanceFormatter = NSLengthFormatter()
    
    lazy var durationFormatter: NSDateComponentsFormatter = {
        let dateComponentsFormatter = NSDateComponentsFormatter()
        dateComponentsFormatter.unitsStyle = .Positional
        return dateComponentsFormatter
    }()
    
    override init() {
        srand48(time(UnsafeMutablePointer<time_t>(bitPattern: 0)))
        
        let randomRun: (NSDate) -> Run = { date in
            let lapCount = arc4random_uniform(20) + 5
            let lapDistance = arc4random_uniform(1000) + 1
            
            var laps: [NSTimeInterval] = []
            
            for _ in 0 ..< lapCount {
                // Pace is in m/s. 9 minutes per mile is about 3 meters per second.
                // Generate a random pace between ~7.5 min/mi and ~10.5 min/mi.
                let speed = 3.0 + (drand48() - 0.5) // in meters per second
                let lapDuration: NSTimeInterval = Double(lapDistance) / speed
                
                laps.append(lapDuration)
            }
            
            let run = Run(distance: Double(lapDistance * lapCount),
                laps: laps,
                startDate: date)
            
            return run
        }
        
        runs = []
        
        for i in 0 ..< 5 {
            runs?.append(randomRun(NSDate().dateByAddingTimeInterval(Double(i)
                * 24 * 60 * 60)))
        }
    }
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        if let run = context as? Run {
            runs?.insert(run, atIndex: 0)
            
            runTable.insertRowsAtIndexes(NSIndexSet(index: 0),
                withRowType: "RunRow")
            
            if let rowc = runTable.rowControllerAtIndex(0) as? RunLogRowController {
                configureRow(rowc, forRun: run)
            }
            
            becomeCurrentPage()
        }
    }
    
    override func willActivate() {
        super.willActivate()
        
        guard let runs = runs else { return }
        
        runTable.setNumberOfRows(runs.count, withRowType: "RunRow")  
        
        for i in 0 ..< runTable.numberOfRows { 
            guard let rowController = runTable.rowControllerAtIndex(i)
                as? RunLogRowController else { continue }
            
            configureRow(rowController, forRun: runs[i])
        }
    }

    override func table(table: WKInterfaceTable,
        didSelectRowAtIndex rowIndex: Int) {
            NSLog("User tapped on row \(rowIndex)")
    }
    
    override func contextForSegueWithIdentifier(segueIdentifier: String,
        inTable table: WKInterfaceTable, rowIndex: Int) -> AnyObject? {
            if segueIdentifier == "ShowRunDetails" {
                guard let runs = runs where runs.count > rowIndex else {
                    return nil
                }
            
                return runs[rowIndex]
            }
            
            return nil
    }
    
    func configureRow(rowController: RunLogRowController, forRun run: Run) {
        rowController.dateFormatter = dateFormatter
        rowController.distanceFormatter = distanceFormatter
        rowController.durationFormatter = durationFormatter
        
        rowController.configure(date: run.startDate,
            distance: run.distance,
            duration: run.duration)
    }
    
}
