//
//  Track.swift
//  TapALap
//
//  Created by Jeff Kelley on 10/23/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import Foundation
import WatchConnectivity

class Track {
    let name: String
    let lapDistance: Double // in meters
    
    init(name: String, lapDistance: Double) {
        self.name = name
        self.lapDistance = lapDistance
    }
    
    func dictionaryRepresentation() -> [String: AnyObject] {
        return ["Name": name, "LapDistance": lapDistance]
    }
    
    init?(dictionaryRepresentation dictionary: [String: AnyObject]) {
        guard let name = dictionary["Name"] as? String,
            lapDistance = dictionary["LapDistance"] as? Double
            else {
                self.name = ""
                self.lapDistance = 0
                
                return nil
        }
        
        self.name = name
        self.lapDistance = lapDistance
    }
    
    static func savedTracks() -> [Track] {
        guard let trackDictionaries = NSUserDefaults.standardUserDefaults()
            .objectForKey("SavedTracks") as? [[String: AnyObject]]
            else { return [] }
        
        return trackDictionaries.flatMap(Track.init)
    }
    
    #if os(watchOS)

    func save() {
        var tracks = Track.savedTracks()
        
        guard !tracks.contains(self) else { return }
        
        tracks.append(self)
        
        Track.saveTracks(tracks)
    }
    
    func delete() {
        var tracks = Track.savedTracks()
        
        guard let trackIndex = tracks.indexOf(self) else { return }
        
        tracks.removeAtIndex(trackIndex)
        
        Track.saveTracks(tracks)
    }
    
    static func saveTracks(tracks: [Track]) {
        let trackDictionaries: [[String: AnyObject]] = tracks.map {
            $0.dictionaryRepresentation()
        }
        
        do {
            let newContext = ["Tracks": trackDictionaries]
            
            try WCSession.defaultSession().updateApplicationContext(newContext)
        }
        catch let error {
            NSLog("Error saving tracks to application context: \(error).")
        }
        
        NSUserDefaults.standardUserDefaults().setObject(trackDictionaries,
            forKey: "SavedTracks")
    }
    #endif
    
}

func ==(lhs: Track, rhs: Track) -> Bool {
    return lhs.name == rhs.name && lhs.lapDistance == rhs.lapDistance
}

extension Track: Equatable {}
