//
//  TrackSelectionInterfaceController.swift
//  TapALap
//
//  Created by Jeff Kelley on 12/30/15.
//  Copyright © 2015 The Pragmatic Bookshelf. All rights reserved.
//

import WatchKit
import Foundation

class TrackRowController: NSObject {
    
    @IBOutlet weak var nameLabel: WKInterfaceLabel!
    @IBOutlet weak var distanceLabel: WKInterfaceLabel!
    
}

class TrackSelectionInterfaceController: WKInterfaceController,
TrackSelectionReceiver {
    
    weak var trackReceiver: TrackSelectionReceiver?

    
    // Inside of the TrackSelectionInterfaceController
    @IBOutlet weak var table: WKInterfaceTable!
    
    var tracks: [Track] {
        return Track.savedTracks().sort { $0.name < $1.name }
    }
    
    lazy var lapDistanceFormatter = NSLengthFormatter()
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        
        if let receiver = context as? TrackSelectionReceiver {
            self.trackReceiver = receiver
        }
    }
    
    override func willActivate() {
        super.willActivate()
        
        loadTableData()
    }
    
    func loadTableData() {
        table.setNumberOfRows(tracks.count, withRowType: "TrackRow")
        
        for i in 0 ..< table.numberOfRows {
            guard let rowController = table.rowControllerAtIndex(i)
                as? TrackRowController else { continue }
            
            let track = tracks[i]
            
            rowController.nameLabel.setText(track.name)
            
            rowController.distanceLabel.setText(
                lapDistanceFormatter.stringFromMeters(track.lapDistance))
        }
    }
    
    override func contextForSegueWithIdentifier(
        segueIdentifier: String) -> AnyObject? {
            if segueIdentifier == "AddNewTrack" {
                return self
            }
            
            return nil
    }

    override func table(table: WKInterfaceTable,
        didSelectRowAtIndex rowIndex: Int) {
            trackReceiver?.receiveTrack(tracks[rowIndex])
    }
    
    func receiveTrack(track: Track) {
        dismissController()
        
        track.save()
        loadTableData()
        trackReceiver?.receiveTrack(track)
        
    }
    
}
