//
//  TrackListTableViewController.swift
//  TapALap
//
//  Created by Jeff Kelley on 1/21/16.
//  Copyright © 2016 The Pragmatic Bookshelf. All rights reserved.
//

import UIKit
import WatchConnectivity

class TrackListTableViewController: UITableViewController {

    override func viewDidLoad() {
        super.viewDidLoad()
        registerForTrackNotifications()

        navigationItem.rightBarButtonItem = self.editButtonItem()
    }
    
    func registerForTrackNotifications() {
        NSNotificationCenter.defaultCenter().addObserver(self,
            selector: "applicationContextChanged",
            name: "ApplicationContextChanged",
            object: nil)
    }
    
    func applicationContextChanged() {
        NSOperationQueue.mainQueue().addOperationWithBlock {
            self.tableView.reloadData()
        }
    }
    
    var tracks: [Track] {
        guard let trackDictionaries = WCSession.defaultSession()
            .receivedApplicationContext["Tracks"] as? [[String: AnyObject]]
            else { return [] }

        let pendingDeletedTracks = WCSession.defaultSession()
            .outstandingUserInfoTransfers 
            .map { $0.userInfo } 
            .flatMap { $0["TrackToDelete"] as? [String: AnyObject] } 
            .flatMap(Track.init) 
        
        return trackDictionaries.flatMap(Track.init).sort { $0.name < $1.name }
            .filter { !pendingDeletedTracks.contains($0) } 
    }

    // MARK: - Table view data source

    override func tableView(tableView: UITableView,
        numberOfRowsInSection section: Int) -> Int {
            return tracks.count
    }
    
    override func tableView(tableView: UITableView,
        cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
            let reuseIdentifier = "TrackCell"
            
            let cell: UITableViewCell
            
            if let reusedCell = tableView.dequeueReusableCellWithIdentifier(
                reuseIdentifier) {
                    cell = reusedCell
            }
            else {
                cell = UITableViewCell(style: .Value1,
                    reuseIdentifier: reuseIdentifier)
            }
            
            if tracks.count > indexPath.row {
                let track = tracks[indexPath.row]
                
                cell.textLabel?.text = track.name
                
                cell.detailTextLabel?.text = NSLengthFormatter()
                    .stringFromMeters(track.lapDistance)
            }
            
            return cell
    }

    override func tableView(tableView: UITableView,
        canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
            return true
    }

    override func tableView(tableView: UITableView,
        commitEditingStyle editingStyle: UITableViewCellEditingStyle,
        forRowAtIndexPath indexPath: NSIndexPath) {
            if editingStyle == .Delete {
                let track = tracks[indexPath.row]
                
                WCSession.defaultSession().transferUserInfo(
                    ["TrackToDelete": track.dictionaryRepresentation()])

                tableView.deleteRowsAtIndexPaths([indexPath],
                    withRowAnimation: .Automatic)
            }
    }

}
